@@ -61,7 +61,7 @@ class jPro(jpSearch, jpDate, jpCat, jpSocial):
 if __name__ == '__main__':
     uri = f"mongodb://192.168.1.180:27017"
     t = jPro(dbUri=uri, dbName="research")
-    t.add_pub_date()
+    print(t.get_document_count())
     # r = t.search_by_date_range("ripple", "July 01 2022", "August 16 2022", limit=35)
     # print(r)
 #     r = t.get_method_names()
